require 'spec_helper'

describe Redify::Core do

  let (:record) { User.find 1, :skip_redify => true }
  let (:namespace) { Redify::Settings.namespace }

  describe '.get_namespaced_key_name_for' do
    subject { lambda {|options| Redify::Core.get_namespaced_key_name_for(options) } }
    it { expect(subject.call(:resource => User, :collection => "All")).to eq("#{namespace}:Users:All") }
    it { expect(subject.call(:resource => User, :collection => "OtherStuff")).to eq("#{namespace}:Users:Collections:OtherStuff") }
    it { expect(subject.call(:record => record)).to eq("#{namespace}:User:1") }
    it { expect(subject.call(:resource => User, :id => 1)).to eq("#{namespace}:User:1") }
  end

  describe '.get_key_name_for' do
    subject { lambda {|options| Redify::Core.get_key_name_for(options) } }
    it { expect(subject.call(:resource => User, :collection => "All")).to eq("Users:All") }
    it { expect(subject.call(:resource => User, :collection => "OtherStuff")).to eq("Users:Collections:OtherStuff") }
    it { expect(subject.call(:record => record)).to eq("User:1") }
    it { expect(subject.call(:resource => User, :id => 1)).to eq("User:1") }
  end

  describe '.get_key_name_for_collection' do
    subject { lambda {|options| Redify::Core.get_key_name_for_collection(options) } }
    it { expect(subject.call(:resource => User, :collection => "All")).to eq("Users:All") }
    it { expect(subject.call(:resource => User, :collection => "OtherStuff")).to eq("Users:Collections:OtherStuff") }
  end

  describe '.get_key_name_for_record' do
    subject { lambda {|record| Redify::Core.get_key_name_for_record(record) } }
    it { expect(subject.call(record)).to eq("User:1") }
  end

  describe '.get_key_name_for_resource_and_id' do
    subject { lambda {|options| Redify::Core.get_key_name_for_resource_and_id(options) } }
    it { expect(subject.call(:resource => User, :id => 1)).to eq("User:1") }
  end

end
